﻿using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Reflection;
using Isis.Helpers;
using NUnit.Framework;

namespace Isis.Tests
{
    [TestFixture]
    public class AssemblyListTester
    {
        [Test]
        public void GetAssemblyFolderShouldBeginWithDriveLetter()
        {
            string myPath = new ApplicationFolder().GetAssemblyFolder(Assembly.GetExecutingAssembly());
            Debug.Print(myPath);
            Assert.AreEqual(Directory.GetCurrentDirectory().Substring(0,2), myPath.Substring(0, 2));
        }

        [Test]
        public void IsDebugBuildExtensionMethodShouldReturnFalseForNUnitFramework()
        {
            IList<Assembly> myAssemblies = new ApplicationFolder().ListRunningAssemblies();

            Assembly nUnitFile = myAssemblies.Where(f => f.FullName.Contains("nunit.framework")).First();

            Assert.IsNotNull(nUnitFile);
            Assert.IsFalse(nUnitFile.IsDebugBuild());
        }

        [Test]
        public void IsDebugBuildExtensionMethodShouldReturnTrueForThisTestAssembly()
        {
            Assembly thisAssembly = Assembly.GetExecutingAssembly();
            Assert.IsTrue(thisAssembly.IsDebugBuild());
        }

        [Test]
        public void ListFilesInFolderShouldReturnFilesForCurrentAssemblyFolder()
        {
            var appFolder = new ApplicationFolder();
            string path = appFolder.GetAssemblyFolder(Assembly.GetExecutingAssembly());
            FileInfo[] myFiles = appFolder.ListFilesInFolder(path, "*.*");

            Assert.GreaterOrEqual(myFiles.Length, 1);
            foreach (FileInfo file in myFiles)
            {
                Debug.Print(file.Name);
            }
        }

        [Test]
        public void ListRunningAssembliesShouldShowAllAssembliesInBinFolder()
        {
            var myApp = new ApplicationFolder();
            IList<Assembly> myAssemblies = myApp.ListRunningAssemblies();

            Assert.GreaterOrEqual(myAssemblies.Count, 5);
        }
    }
}