using System.Web.Routing;
using Isis.Parsers.Impl;
using NUnit.Framework;

namespace Isis.Tests.ControlPanelHandlerTests
{
    [TestFixture]
    public class RouteDataParserTester
    {
        [Test]
        public void WhenRequestIsNullTheActionIsEmpty()
        {
            var routeDataParser = new RouteDataParser();

            string action = routeDataParser.GetAction(null);

            Assert.AreEqual(string.Empty, action);
        }

        [Test]
        public void WhenRouteDataIsNullTheActionIsEmpty()
        {
            var requestContext = new RequestContext {RouteData = null};
            var routeDataParser = new RouteDataParser();

            string action = routeDataParser.GetAction(requestContext);

            Assert.AreEqual(string.Empty, action);
        }

        [Test]
        public void WhenRouteDataHasNoActionKeyTheActionIsEmpty()
        {
            var requestContext = new RequestContext { RouteData = new RouteData() };
            var routeDataParser = new RouteDataParser();

            string action = routeDataParser.GetAction(requestContext);

            Assert.AreEqual(string.Empty, action);
        }

        [Test]
        public void WhenRouteDataContainsActionTheActionIsReturned()
        {
            var routeData = new RouteData();
            const string expected = "foo";
            routeData.Values.Add("action", expected);
            var requestContext = new RequestContext { RouteData = routeData };
            var routeDataParser = new RouteDataParser();

            string action = routeDataParser.GetAction(requestContext);

            Assert.AreEqual(expected, action);
        }

        [Test]
        public void WhenRouteDataContainsActionAndControllerTheActionAndControllerAreReturned()
        {
            var routeData = new RouteData();
            const string expectedAction = "action";
            const string expectedController = "controller";
            routeData.Values.Add("action", expectedAction);
            routeData.Values.Add("controller", expectedController);
            var requestContext = new RequestContext { RouteData = routeData };
            var routeDataParser = new RouteDataParser();

            string action = routeDataParser.GetAction(requestContext);
            Assert.AreEqual(expectedAction, action);

            string controller = routeDataParser.GetController(requestContext);
            Assert.AreEqual(expectedController, controller);
        }

        [Test]
        public void WhenRouteDataContainsActionControllerAndParameterAllThreeValuesAreReturned()
        {
            var routeData = new RouteData();
            const string expectedAction = "theaction";
            const string expectedController = "thecontroller";
            const string expectedParameter = "theparameter";
            routeData.Values.Add("action", expectedAction);
            routeData.Values.Add("controller", expectedController);
            routeData.Values.Add("parameter", expectedParameter);
            var requestContext = new RequestContext { RouteData = routeData };
            var routeDataParser = new RouteDataParser();

            string action = routeDataParser.GetAction(requestContext);
            Assert.AreEqual(expectedAction, action);

            string controller = routeDataParser.GetController(requestContext);
            Assert.AreEqual(expectedController, controller);

            string parameter = routeDataParser.GetParameter(requestContext);
            Assert.AreEqual(expectedParameter, parameter);
        }
    }
}