﻿using Isis.Helpers.Impl;
using NUnit.Framework;

namespace Isis.Tests.Helpers
{
    [TestFixture]
    class TableRendererHelperTester
    {
        private TableRenderingHelper _tableRenderingHelper;

        [SetUp]
        public void Init()
        {
            _tableRenderingHelper = new TableRenderingHelper();
        }

        [Test]
        public void RenderCellWrapsCellContentInTdTag()
        {
            const string expected = "<td>cellContent</td>";

            var actual = _tableRenderingHelper.RenderCell("cellContent");

            Assert.AreEqual(expected, actual);
        }

        [Test]
        public void RenderCellWrapsCellContentInTdTagAndAddsCssClassWhenProvided()
        {
            const string expected = "<td class=\"cssClass\">cellContent</td>";

            var actual = _tableRenderingHelper.RenderCell("cellContent", "cssClass");

            Assert.AreEqual(expected, actual);
        }

        [Test]
        public void RenderRowCreatesTdCellAndReturnsTrElement()
        {
            const string expected = "<tr><td>foo</td></tr>";

            var actual = _tableRenderingHelper.RenderRow(new[] {"foo"});

            Assert.AreEqual(expected, actual);
        }

        [Test]
        public void RenderRowCreatesTdCellsForCollectionAndReturnsTrElement()
        {
            const string expected = "<tr><td>foo</td><td>bar</td></tr>";

            var actual = _tableRenderingHelper.RenderRow(new[] {"foo", "bar"});

            Assert.AreEqual(expected, actual);
        }

        [Test]
        public void RenderHeaderRowReturnsHtmlForGivenCollectionOfHeadings()
        {
            const string expected = "<thead><tr><th>foo</th><th>bar</th></tr></thead>";

            var actual = _tableRenderingHelper.RenderHeaderRow(new[] {"foo", "bar"});

            Assert.AreEqual(expected, actual);
        }
    }
}
