﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using Isis.Views;
using System.IO;

namespace Isis.Tests
{
    [TestFixture]
    public class SubTabWriterRenderSubTabsShould
    {
        public ControllerRepository _controllerRepository;
        TextWriter writer;

        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void BlowUpWhenSubtabsAreNull()
        {
            var subTabWriter = new SubTabWriter();
            string result = subTabWriter.RenderSubTabs(String.Empty, string.Empty, null, null, string.Empty);
        }
        [Test]
        public void DisplayDefaultIfSubtabsArePresent()
        {
            var subTabWriter = new SubTabWriter();
            var mySubTabList = new List<String>()
            {
                "firstoneshouldbedefault", "secondtab", "thirdtab"
            };

            string result = subTabWriter.RenderSubTabs("/isis", "Files", mySubTabList, writer, "");

            Assert.That(result.Contains("class=\"selected\">firstoneshouldbedefault"));
        }
        [Test]
        public void DisplayCurrentlySelectedSubTab()
        {
            var subTabWriter = new SubTabWriter();
            var mySubTabList = new List<String>()
            {
                "firstoneshouldbedefault", "secondtab", "thirdtab"
            };

            string result = subTabWriter.RenderSubTabs("/isis", "Files", mySubTabList, writer, "secondtab");

            Assert.That(result.Contains("class=\"selected\">secondtab"));
        }
        [Test]
        public void DisplaysTabAsLinkWhenNotSelected()
        {
            var subTabWriter = new SubTabWriter();
            var mySubTabList = new List<String>()
            {
                "firstoneshouldbedefault", "secondtab", "thirdtab"
            };

            string result = subTabWriter.RenderSubTabs("/isis", "Files", mySubTabList, writer, "secondtab");

            Assert.That(!result.Contains("<li><a href=\"{0}/{1}/{2}\">firstoneshouldbedefault, thirdtab"));
        }
       
    }
}
